@@ -1,4 +1,8 @@
-import typing as ty
+from typing import Callable, Literal, Union
+
+from typing_extensions import TypeGuard
+
+from .typing_utils import T
 
 
 class _Missed:
@@ -12,29 +16,29 @@ class _Missed:
     def __repr__(self) -> str:
         return "MISSING"
 
-    def __bool__(self) -> ty.Literal[False]:
+    def __bool__(self) -> Literal[False]:
         return False
 
 
 MISSING = _Missed()
 
 
-type Maybe[T] = T | _Missed
+Maybe = Union[T, _Missed]
 """
 Nullable[int] == int | NULL
 """
 
 
-def is_provided[T](value: Maybe[T]) -> ty.TypeGuard[T]:
+def is_provided(value: Maybe[T]) -> TypeGuard[T]:
     """
     Check if the value is not MISSING.
     """
     return value is not MISSING
 
 
-def use_var[
-    T
-](obj_type: type[T]) -> tuple[ty.Callable[[], Maybe[T]], ty.Callable[[T], None]]:
+def use_var(
+    obj_type: type[T],
+) -> tuple[Callable[[], Maybe[T]], Callable[[T], None]]:
     instance: Maybe[T] = MISSING
 
     def getter() -> Maybe[T]:
