@@ -2,8 +2,12 @@ from typing import Generic, TypeVar
 
 import pytest
 
-from ididi import DependencyGraph
-from ididi.errors import ForwardReferenceNotFoundError, MissingReturnTypeError
+from ididi import DependencyGraph, Ignore
+from ididi.errors import (
+    ForwardReferenceNotFoundError,
+    UnsolvableDependencyError,
+    UnsolvableReturnTypeError,
+)
 
 dg = DependencyGraph()
 # Define a generic type variable
@@ -28,17 +32,13 @@ class Dog(Animal[str]):
         return f"{self.value} says woof!"
 
 
-# Factory class with generic return type
-@dg.node
-def animal_factory(animal_type: str) -> Animal[str]:
-    return Dog(animal_type)
-
-
-# Test cases
 def test_factory_generic_return():
     # Create a Dog instance using the factory
-    dog = animal_factory("Buddy")
+    # Factory class with generic return type
+    def animal_factory(animal_type: Ignore[str]) -> Animal[str]:
+        return Dog(animal_type)
 
+    dog = dg.resolve(animal_factory, animal_type="Buddy")
     assert isinstance(dog, Animal)
     assert isinstance(dog, Dog)
     assert dog.get_value() == "Buddy"
@@ -46,7 +46,7 @@ def test_factory_generic_return():
 
 
 def test_emptry_return_factory():
-    with pytest.raises(MissingReturnTypeError):
+    with pytest.raises(UnsolvableReturnTypeError):
 
         @dg.node
         def animal_factory(animal_type: str): ...
@@ -55,3 +55,30 @@ def test_emptry_return_factory():
 
         @dg.node
         def animal_factory(animtal_type: str = "test") -> "Normal": ...
+
+
+class UserService: ...
+
+
+@dg.node
+def user_service_factory() -> "UserService": ...
+
+
+def test_forward_factory():
+    dg.node(user_service_factory)
+    dg.analyze(user_service_factory)
+
+
+# Factory class with generic return type
+def animal_factory(animal_type: str) -> Animal[str]:
+    return Dog(animal_type)
+
+
+def test_direct_resolve_with_override():
+    dg = DependencyGraph()
+    # this should not raise ididi.errors.UnsolvableDependencyError
+    # since animal_type is provided, we should not care about resolvability
+    with pytest.raises(UnsolvableDependencyError):
+        dg.analyze(animal_factory)
+
+    dg.resolve(animal_factory, animal_type="cat")
