@@ -1,23 +1,24 @@
+import typing as ty
 
 from ididi import DependencyGraph
 
 dg = DependencyGraph()
 
+
 class TokenBucketFactory:
     def __init__(
         self,
         redis: str,
         script: int,
-        keyspace: str | None = None,
+        keyspace: ty.Union[str, None] = None,
     ):
         self.cache = redis
         self.script = script
         self.keyspace = keyspace
 
+
 @dg.node
-def token_bucket_factory(
-    settings: str = "", aiocache: str = ""
-) -> TokenBucketFactory:
+def token_bucket_factory(settings: str = "", aiocache: str = "") -> TokenBucketFactory:
     keyspace = settings.redis.keyspaces.THROTTLER / "user_request"
     script = settings.redis.TOKEN_BUCKET_SCRIPT
     script_func = aiocache.load_script(script)
@@ -25,4 +26,4 @@ def token_bucket_factory(
         redis=aiocache,
         script=script_func,
         keyspace=keyspace,
-    )
\ No newline at end of file
+    )
