@@ -15,7 +15,9 @@ def test_subclass_of_protocol():
 
     class ChatSession(IEntity): ...
 
-    class IRepository[TEntity: IEntity](ty.Protocol): ...
+    E = ty.TypeVar("E", bound=IEntity)
+
+    class IRepository(ty.Protocol[E]): ...
 
     class ISessionRepository(IRepository[ChatSession]): ...
 
