@@ -1,10 +1,14 @@
 import inspect
 import sys
+import typing as ty
 from abc import ABC, abstractmethod
+from datetime import datetime
+from typing import Optional
 from unittest import mock
 
 import pytest
 
+from ididi import DependencyGraph
 from ididi.errors import (
     ABCNotImplementedError,
     AsyncResourceInSyncError,
@@ -15,7 +19,8 @@ from ididi.errors import (
     TopLevelBulitinTypeError,
     UnsolvableDependencyError,
 )
-from ididi.graph import DependencyGraph
+
+T = ty.TypeVar("T")
 
 
 def test_import_graphviz_failure():
@@ -101,22 +106,27 @@ def test_get_dependent_types(dg: DependencyGraph):
     assert AuthService in database_dependents
 
 
+@pytest.mark.debug
 def test_node_signature_change_after_factory(dg: DependencyGraph):
     class UserService:
         def __init__(self, repo: UserRepository, auth: AuthService, name: str = "user"):
             self.repo = repo
             self.auth = auth
 
-    dg.static_resolve(UserService)
+    dg.analyze(UserService)
     node = dg.nodes[UserService]
-    assert len(node.signature.dprams) == 3
+    print(node.dependencies)
+    print(node.dependencies.signature)
+    print(node.dependencies["name"])
+
+    assert len(node.dependencies) == 3
 
     @dg.node
     def user_service_factory(repo: UserRepository, auth: AuthService) -> UserService:
         return UserService(repo, auth)
 
     node = dg.nodes[UserService]
-    assert len(node.signature.dprams) == 2
+    assert len(node.dependencies) == 2
 
 
 def test_top_level_builtin_dependency(dg: DependencyGraph):
@@ -219,11 +229,11 @@ def test_static_resolve_factory(dg: DependencyGraph):
 
     assert Repository in dg.nodes
 
-    repo = dg.static_resolve(repo_factory)
+    repo = dg.analyze(repo_factory)
     assert Repository in dg.type_registry[Repository]
 
 
-@pytest.mark.asyncio
+@pytest.mark.debug
 async def test_resource_cleanup(dg: DependencyGraph):
     closed_resources: set[str] = set()
 
@@ -264,17 +274,17 @@ async def test_resource_cleanup(dg: DependencyGraph):
     assert closed_resources == {"resource1", "resource2"}
 
 
-def test_node_removal(dg: DependencyGraph):
-    @dg.node
-    class Service:
-        pass
+# def test_node_removal(dg: DependencyGraph):
+#     @dg.node
+#     class Service:
+#         pass
 
-    node = dg.nodes[Service]
-    dg.remove_node(node)
+#     node = dg.nodes[Service]
+#     dg.remove_node(node)
 
-    assert Service not in dg.nodes
+#     assert Service not in dg.nodes
 
-    dg.resolve(Service)
+#     dg.resolve(Service)
 
 
 def test_graph_reset(dg: DependencyGraph):
@@ -311,7 +321,7 @@ def test_node_removal_cleanup(dg: DependencyGraph):
 
     # Get the node and remove it
     node = dg.nodes[Dependency]
-    dg.remove_node(node)
+    dg._remove_node(node)
 
     # Check that all references are cleaned up
     assert Dependency not in dg.nodes
@@ -411,6 +421,7 @@ def test_dependency_override(dg: DependencyGraph):
     assert instance.name == "overridden"
 
 
+@pytest.mark.debug
 def test_nested_dependency_override(dg: DependencyGraph):
     @dg.node
     class Inner:
@@ -484,33 +495,24 @@ def test_type_mapping_cleanup(dg: DependencyGraph):
 
     # Remove implementation
     node = dg.nodes[Implementation]
-    dg.remove_node(node)
+    dg.reset(clear_nodes=True)
 
     # Verify type mapping is cleaned up
     assert Interface not in dg.type_registry or not dg.type_registry[Interface]
 
 
-def test_node_factory(dg: DependencyGraph):
-    factory = dg.factory(UserService, use_async=False)
-    assert callable(factory)
-    assert isinstance(factory(), UserService)
-
-
 @pytest.mark.asyncio
 async def test_graph_without_static_resolve(dg: DependencyGraph):
     # This test specifically needs a new dag instance
-    dg = DependencyGraph(static_resolve=False)
-    async with dg:
+    dg = DependencyGraph()
 
-        @dg.node(reuse=False)
-        class UserService:
-            def __init__(
-                self, repo: UserRepository, auth: AuthService, name: str = "user"
-            ):
-                self.repo = repo
-                self.auth = auth
+    @dg.node(reuse=False)
+    class UserService:
+        def __init__(self, repo: UserRepository, auth: AuthService, name: str = "user"):
+            self.repo = repo
+            self.auth = auth
 
-        dg.resolve(UserService)
+    dg.resolve(UserService)
 
     with pytest.raises(PositionalOverrideError):
         dg.resolve(UserRepository, 1)
@@ -527,25 +529,25 @@ async def test_graph_without_static_resolve(dg: DependencyGraph):
     await dg.aresolve(UserRepository, db="asdf")
 
 
-def test_graph_factory_partial(dg: DependencyGraph):
-    factory = dg.factory(UserService, use_async=False)
-    assert isinstance(factory(), UserService)
+def test_remove_old_node():
+    dg = DependencyGraph()
 
+    class IUser: ...
 
-@pytest.mark.asyncio
-async def test_async_graph_factory(dg: DependencyGraph):
-    factory = dg.factory(UserService, use_async=True)
-    assert isinstance(await factory(), UserService)
+    class User(IUser):
+        def __init__(self, name: str = "user"):
+            self.name = name
 
+    dg.node(User)
 
-def test_graph_replace_node(dg: DependencyGraph):
-    @dg.node
-    class Service:
-        pass
+    def user_factory() -> User:
+        return User("hello")
 
-    node = dg.nodes[Service]
+    dg.node(user_factory)
 
-    dg.replace_node(node, node)
+    assert IUser in dg.type_registry
+    assert User in dg.type_registry
+    assert User in dg.type_registry[IUser]
 
 
 def test_resolve_node_without_annotation():
@@ -567,10 +569,11 @@ def test_resolve_node_without_annotation():
         return Config(a=1)
 
     service = dag.resolve(Service)
+    print(dag.nodes[Config])
     assert service.config.a == 1
 
 
-class GenericService[T]:
+class GenericService(ty.Generic[T]):
     def __init__(self, item: T):
         self.item = item
 
@@ -581,7 +584,7 @@ def test_generic_service_not_supported(dg: DependencyGraph):
 
 
 def test_generic_service_with_default(dg: DependencyGraph):
-    class GenericService[T]:
+    class GenericService(ty.Generic[T]):
         def __init__(self, item: T = "5"):
             self.item = item
 
@@ -600,7 +603,7 @@ def test_node_config_non_transitive(dg: DependencyGraph):
         def __init__(self, b: Base): ...
 
     dg.node(reuse=False)(Sub)
-    dg.static_resolve(Sub)
+    dg.analyze(Sub)
 
     assert dg.nodes[Base].config.reuse == True
 
@@ -616,12 +619,12 @@ def test_partial_node(dg: DependencyGraph):
 
     with pytest.raises(UnsolvableDependencyError):
         dg.node(reuse=False)(Sub)
-        dg.static_resolve(Sub)
+        dg.analyze(Sub)
 
     dg.reset(clear_nodes=True)
 
-    dg.node(partial=True)(Sub)
-    dg.static_resolve(Sub)
+    dg.node(ignore=int)(Sub)
+    dg.analyze(Sub)
     # assert dg.resolve(Sub, age=15).age == 15
     dg.resolve(Sub, age=15)
 
@@ -649,17 +652,19 @@ def test_graph_merge_with_error():
             dg.merge(dg2)
 
 
-def test_graph_static_resolved():
+def test_graph_static_resolved_should_override():
 
     from .test_data import ComplianceChecker, DatabaseConfig
 
     dg = DependencyGraph()
     dg2 = DependencyGraph()
 
-    dg.static_resolve(ComplianceChecker)
+    dg.analyze(ComplianceChecker)
     c = dg.resolve(ComplianceChecker)
-    dg2.static_resolve(DatabaseConfig)
+
+    dg2.analyze(DatabaseConfig)
     d = dg2.resolve(DatabaseConfig)
+    repr(dg.nodes[ComplianceChecker].config)
 
     dg.merge(dg2)
     assert ComplianceChecker in dg and DatabaseConfig in dg
@@ -667,3 +672,66 @@ def test_graph_static_resolved():
     c1, d1 = dg.resolve(ComplianceChecker), dg.resolve(DatabaseConfig)
     assert c1 is c
     assert d1 is d
+
+
+def test_graph_static_resolved_should_not_override():
+
+    from .test_data import ComplianceChecker, DatabaseConfig
+
+    dg = DependencyGraph()
+    dg2 = DependencyGraph()
+
+    def checker_factory() -> ComplianceChecker: ...
+
+    dg.node(checker_factory)
+
+    dg2.analyze(ComplianceChecker)
+    dg2.analyze(DatabaseConfig)
+
+    dg.merge(dg2)
+    assert dg.nodes[ComplianceChecker].factory_type == "function"
+    assert ComplianceChecker in dg and DatabaseConfig in dg
+
+
+def test_factory_override_default_value():
+    dg = DependencyGraph()
+
+    class Database: ...
+
+    DB_SINGLETON = Database()
+
+    class UserRepos:
+        def __init__(self, db: Optional[Database] = None):
+            self.db = db
+
+    class Person:
+        def __init__(self, name: str = "p"):
+            self.name = name
+
+    def db_factory() -> Database:
+        return DB_SINGLETON
+
+    db = dg.resolve(UserRepos).db
+    assert isinstance(db, Database)
+    assert db is not DB_SINGLETON
+    dg.node(db_factory)
+    assert dg.resolve(Database) is DB_SINGLETON
+
+    assert dg.resolve(Person).name == "p"
+
+
+def test_graph_ignore():
+    class Timer:
+        def __init__(self, d: datetime):
+            self._d = d
+
+    dg = DependencyGraph(ignore=datetime)
+    with pytest.raises(TypeError):
+        dg.resolve(Timer)
+
+def test_remove_dependent():
+    class Database: ...
+
+    dg = DependencyGraph()
+
+    dg.remove_dependent(Database)
